@@ -34,34 +34,34 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
 
   $entryarray = array();
   $query1 = "
-            SELECT 
-                mn.*, 
-                mnc.news_category_name, 
-                mnc.long_name, 
-                u.username, 
+            SELECT
+                mn.*,
+                mnc.news_category_name,
+                mnc.long_name,
+                u.username,
                 u.first_name,
-                u.last_name 
-            FROM " . 
+                u.last_name
+            FROM " .
     cms_db_prefix() . "module_news mn
-            LEFT OUTER JOIN " . cms_db_prefix() . "module_news_categories mnc 
-            ON mnc.news_category_id = mn.news_category_id 
-            LEFT OUTER JOIN " . cms_db_prefix() . "users u 
-            ON u.user_id = mn.author_id 
-            WHERE 
-                status = 'published' 
+            LEFT OUTER JOIN " . cms_db_prefix() . "module_news_categories mnc
+            ON mnc.news_category_id = mn.news_category_id
+            LEFT OUTER JOIN " . cms_db_prefix() . "users u
+            ON u.user_id = mn.author_id
+            WHERE
+                status = 'published'
             AND
         ";
 
   $query2 = "
             SELECT count(mn.news_id) as count
-            FROM " . 
+            FROM " .
     cms_db_prefix() . "module_news mn
-            LEFT OUTER JOIN " . cms_db_prefix() . "module_news_categories mnc 
-            ON mnc.news_category_id = mn.news_category_id 
-            LEFT OUTER JOIN " . cms_db_prefix() . "users u 
-            ON u.user_id = mn.author_id 
-            WHERE 
-                status = 'published' 
+            LEFT OUTER JOIN " . cms_db_prefix() . "module_news_categories mnc
+            ON mnc.news_category_id = mn.news_category_id
+            LEFT OUTER JOIN " . cms_db_prefix() . "users u
+            ON u.user_id = mn.author_id
+            WHERE
+                status = 'published'
             AND
         ";
 
@@ -109,7 +109,7 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
     $query1 .= ") AND ";
     $query2 .= ") AND ";
   }
-  
+
   $now = $db->DbTimeStamp(time());
   $query1 .= "(".$db->IfNull('start_time',$db->DBTimeStamp(1))." < ".$now.") ";
   $query2 .= "(".$db->IfNull('start_time',$db->DBTimeStamp(1))." < ".$now.") ";
@@ -131,10 +131,10 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
   switch( $sortby ) {
     case 'news_category':
       if (isset($params['sortasc']) && (strtolower($params['sortasc']) == 'true')) {
-        $query1 .= "ORDER BY mnc.long_name ASC, mn.news_date "; 
+        $query1 .= "ORDER BY mnc.long_name ASC, mn.news_date ";
       } else {
         $query1 .= "ORDER BY mnc.long_name DESC, mn.news_date ";
-      }        
+      }
       break;
 
     case 'random':
@@ -159,22 +159,22 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
 
   if( $sortrandom == false ) {
     if (isset($params['sortasc']) && (strtolower($params['sortasc']) == 'true')) {
-      $query1 .= "ASC"; 
-    } 
+      $query1 .= "ASC";
+    }
     else {
-      $query1 .= "DESC"; 
+      $query1 .= "DESC";
     }
   }
 
-  $pagelimit = 100000;
-
+  $pagelimit = 1000;
   if( isset( $params['pagelimit'] ) ) {
-    $pagelimit = intval($params['pagelimit']);
+      $pagelimit = (int) ($params['pagelimit']);
   }
   else if( isset( $params['number'] ) ) {
-    $pagelimit = intval($params['number']);
+      $pagelimit = (int) ($params['number']);
   }
-	
+  $pagelimit = max(2,min(1000,$pagelimit)); // maximum of 1000 entries.
+
   // Get the number of rows (so we can determine the numer of pages)
   $pagecount = -1;
   $startelement = 0;
@@ -221,7 +221,7 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
 		    $this->CreateFrontendLink($id,$returnid,'default','',
 					      $params, '', true));
   }
-  
+
   if( $pagenumber >= $pagecount ) {
     $smarty->assign('nextpage',$this->Lang('nextpage'));
     $smarty->assign('lastpage',$this->Lang('lastpage'));
@@ -248,7 +248,7 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
   $smarty->assign('pagecount',$pagecount);
   $smarty->assign('oftext',$this->Lang('prompt_of'));
   $smarty->assign('pagetext',$this->Lang('prompt_page'));
-  
+
   $dbresult = '';
   if( $pagelimit < 100000 || $startelement > 0 ) {
     $dbresult = $db->SelectLimit( $query1,$pagelimit,$startelement);
@@ -256,7 +256,7 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
   else {
     $dbresult = $db->Execute($query1);
   }
-  
+
   {
     // build a list of news id's so we can preload stuff from other tables.
     $result_ids = array();
@@ -271,7 +271,7 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
   while( $dbresult && !$dbresult->EOF ) {
     $row = $dbresult->fields;
     $onerow = new stdClass();
-    
+
     $onerow->author_id = $row['author_id'];
     if( $onerow->author_id > 0 ) {
       $onerow->author = $row['username'];
@@ -311,7 +311,7 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
     $onerow->fields = news_ops::get_fields($row['news_id'],TRUE);
     $onerow->fieldsbyname = $onerow->fields; // dumb, I know.
     $onerow->file_location = $gCms->config['uploads_url'].'/news/id'.$row['news_id'];
-    
+
     $moretext = isset($params['moretext'])?$params['moretext']:$this->Lang('more');
     $sendtodetail = array('articleid'=>$row['news_id']);
     if (isset($params['showall'])) {
@@ -323,7 +323,7 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
     if (isset($params['detailtemplate'])) {
       $sendtodetail['detailtemplate'] = $params['detailtemplate'];
     }
-    
+
     $prettyurl = $row['news_url'];
     if( $prettyurl == '' ) {
       $aliased_title = munge_string_to_url($row['news_title']);
@@ -361,7 +361,7 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
 
   foreach( $params as $key => $value ) {
     if( $key == 'mact' || $key == 'action' ) continue;
-    
+
     $smarty->assign('param_'.$key,$value);
   }
 
@@ -370,10 +370,10 @@ if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_
     $catName = $params['category'];
   }
   else if (isset($params['category_id'])) {
-    $catName = $db->GetOne('SELECT news_category_name FROM '.cms_db_prefix() . 'module_news_categories where news_category_id=?',array($params['category_id']));		
+    $catName = $db->GetOne('SELECT news_category_name FROM '.cms_db_prefix() . 'module_news_categories where news_category_id=?',array($params['category_id']));
   }
   $smarty->assign('category_name',$catName);
- 
+
   unset($params['pagenumber']);
   $items = news_ops::get_categories($id,$params,$returnid);
   $smarty->assign('count', count($items));
