@@ -2,6 +2,8 @@
 // calguy1000: this action is officially deprecated.
 
 if (!isset($gCms)) exit;
+if( !$this->GetPreference('fesubmit_allowed',0) ) return;
+
 $title = '';
 $extra = '';
 $content = '';
@@ -18,6 +20,18 @@ $category_id = $this->GetPreference('default_category', '');
 $do_send_email = false;
 $do_redirect = false;
 
+function __newsCleanHTML($html)
+{
+    $i = 0;
+    for( $i = 0; $i < 10; $i++ ) {
+        $old = $html;
+        $html = preg_replace('/<script\b[^>]*>(.*?)<\/script>/is', "", $html);
+        $html = str_replace('script:','___',$html);
+        if( strcmp($old,$html) == 0 ) break;
+    }
+    return $html;
+}
+
 // handle the page to go to after cancel or submit.
 $dest_page = $returnid;
 $tmp = $this->GetPreference('fesubmit_redirect');
@@ -42,50 +56,51 @@ if( $userid == '' ) {
 }
 
 if (isset($params['category'])) {
-  $query = 'SELECT news_category_id FROM '.cms_db_prefix().'module_news_categories WHERE news_category_name = ?';
-  $tmp = $db->GetOne($query,array($params['category']));
-  if( $tmp ) $category_id = $tmp;
+    $query = 'SELECT news_category_id FROM '.cms_db_prefix().'module_news_categories WHERE news_category_name = ?';
+    $category = strip_tags($params['category']);
+    $tmp = $db->GetOne($query,array($category));
+    if( $tmp ) $category_id = (int) $tmp;
 }
 
 if( isset( $params['cancel'] ) ) $this->RedirectContent($dest_page);
 
 if( isset( $params['submit'] ) ) {
-  if( isset($params['content']) ) $content = cms_html_entity_decode($params['content']);
+    if( isset($params['content']) ) $content = __newsCleanHTML(cms_html_entity_decode($params['content']));
 
-  if( isset($params['summary']) ) $summary = cms_html_entity_decode($params['summary']);
-  if( isset($params['extra']) ) $extra = cms_html_entity_decode($params['extra']);
-  if( isset($params['category_id']) ) $category_id = $params['category_id'];
-  if (isset($params['input_category']))	$category_id = $params['input_category'];
+    if( isset($params['summary']) ) $summary = __newsCleanHTML(cms_html_entity_decode($params['summary']));
+    if( isset($params['extra']) ) $extra = strip_tags(cms_html_entity_decode($params['extra']));
+    if( isset($params['category_id']) ) $category_id = (int) $params['category_id'];
+    if (isset($params['input_category']))	$category_id = (int) $params['input_category'];
 
   if (isset($params['postdate_Month'])) {
-    $postdate = mktime($params['postdate_Hour'], $params['postdate_Minute'], 
-		       $params['postdate_Second'], $params['postdate_Month'], 
-		       $params['postdate_Day'], $params['postdate_Year']);
+      $postdate = mktime((int)$params['postdate_Hour'], (int) $params['postdate_Minute'],
+                         (int)$params['postdate_Second'], (int) $params['postdate_Month'],
+                         (int)$params['postdate_Day'], (int) $params['postdate_Year']);
   }
 
   if (isset($params['startdate_Month'])) {
-    $startdate = mktime($params['startdate_Hour'], $params['startdate_Minute'], 
-			$params['startdate_Second'], $params['startdate_Month'], 
-			$params['startdate_Day'], $params['startdate_Year']);
+      $startdate = mktime((int)$params['startdate_Hour'], (int) $params['startdate_Minute'],
+                          (int)$params['startdate_Second'], (int) $params['startdate_Month'],
+                          (int)$params['startdate_Day'], (int) $params['startdate_Year']);
   }
-    
+
   if (isset($params['enddate_Month'])) {
-    $enddate = mktime($params['enddate_Hour'], $params['enddate_Minute'], 
-		      $params['enddate_Second'], $params['enddate_Month'], 
-		      $params['enddate_Day'], $params['enddate_Year']);
+      $enddate = mktime((int)$params['enddate_Hour'], (int) $params['enddate_Minute'],
+                        (int)$params['enddate_Second'], (int) $params['enddate_Month'],
+                        (int)$params['enddate_Day'], (int) $params['enddate_Year']);
   }
 
   $error = false;
   if( $startdate > $enddate ) {
-    $error = true;
-    $smarty->assign('error',$this->Lang('startdatetoolate'));
+      $error = true;
+      $smarty->assign('error',$this->Lang('startdatetoolate'));
   }
 
   if( isset($params['title'] ) ) $title = strip_tags(cms_html_entity_decode($params['title']));
 
   if( $title == '' ) {
-    $error = true;
-    $smarty->assign('error',$this->Lang('notitlegiven'));
+      $error = true;
+      $smarty->assign('error',$this->Lang('notitlegiven'));
   }
 
   if( $content == '' ) {
@@ -125,19 +140,19 @@ if( isset( $params['submit'] ) ) {
 
   if( $error == false ) {
     // and generate the insert query
-    $query = 'INSERT INTO '.cms_db_prefix().'module_news 
+    $query = 'INSERT INTO '.cms_db_prefix().'module_news
               (news_id, news_category_id, news_title, news_data, summary,
-               news_extra, status, news_date, start_time, end_time, create_date, 
-               modified_date,author_id) 
+               news_extra, status, news_date, start_time, end_time, create_date,
+               modified_date,author_id)
               VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)';
-    $dbr = $db->Execute($query, 
-			array($articleid, $category_id, $title, 
-			      $content, $summary, $extra, $status, 
-			      trim($db->DBTimeStamp($postdate), "'"), 
-			      trim($db->DBTimeStamp($startdate), "'"), 
-			      trim($db->DBTimeStamp($enddate), "'"), 
-			      trim($db->DBTimeStamp(time()), "'"), 
-			      trim($db->DBTimeStamp(time()), "'"), 
+    $dbr = $db->Execute($query,
+			array($articleid, $category_id, $title,
+			      $content, $summary, $extra, $status,
+			      trim($db->DBTimeStamp($postdate), "'"),
+			      trim($db->DBTimeStamp($startdate), "'"),
+			      trim($db->DBTimeStamp($enddate), "'"),
+			      trim($db->DBTimeStamp(time()), "'"),
+			      trim($db->DBTimeStamp(time()), "'"),
 			      $userid));
     if( $dbr ) {
       // handle the custom fields
@@ -167,15 +182,15 @@ if( isset( $params['submit'] ) ) {
       $do_redirect = true;
 
       // send an event
-      @$this->SendEvent('NewsArticleAdded', 
-			array('news_id' => $articleid, 
-			      'category_id' => $category_id, 
-			      'title' => $title, 
-			      'content' => $content, 
-			      'summary' => $summary, 
-			      'status' => $status, 
-			      'start_time' => $startdate, 
-			      'end_time' => $enddate, 
+      @$this->SendEvent('NewsArticleAdded',
+			array('news_id' => $articleid,
+			      'category_id' => $category_id,
+			      'title' => $title,
+			      'content' => $content,
+			      'summary' => $summary,
+			      'status' => $status,
+			      'start_time' => $startdate,
+			      'end_time' => $enddate,
 			      'useexp' => $useexp));
 
       // put mention into the admin log
@@ -205,19 +220,19 @@ $smarty->assign('endform',$this->CreateFormEnd());
 $smarty->assign('hidden', $this->CreateInputHidden($id,'category_id',$category_id));
 $smarty->assign('titletext', $this->Lang('title'));
 $smarty->assign('inputtitle', $this->CreateInputText($id, 'title', $title, 30, 255));
-$smarty->assign('inputcategory', 
-		$this->CreateInputDropdown($id, 'input_category', $categorylist, -1, 
+$smarty->assign('inputcategory',
+		$this->CreateInputDropdown($id, 'input_category', $categorylist, -1,
 					   $category_id));
 $smarty->assign('extratext',$this->Lang('extra'));
 $smarty->assign('inputextra',$this->CreateInputText($id,'extra',$extra,30,255));
 $smarty->assign('inputcontent', $this->CreateTextArea(true, $id, $content, 'content'));
 $smarty->assign('hide_summary_field',$this->GetPreference('hide_summary_field','0'));
-$smarty->assign('inputsummary', 
-		$this->CreateTextArea($this->GetPreference('allow_summary_wysiwyg',1), $id, 
+$smarty->assign('inputsummary',
+		$this->CreateTextArea($this->GetPreference('allow_summary_wysiwyg',1), $id,
 				      $summary, 'summary'));
 $smarty->assign_by_ref('postdate', $postdate);
 $smarty->assign('postdateprefix', $id.'postdate_');
-$smarty->assign('inputexp', 
+$smarty->assign('inputexp',
 		$this->CreateInputCheckbox($id, 'useexp', '1', $useexp, 'class="pagecheckbox"'));
 $smarty->assign_by_ref('startdate', $startdate);
 $smarty->assign('startdateprefix', $id.'startdate_');
