@@ -1,4 +1,6 @@
 <?php
+$lang['warn_fesubmit_deprecated'] = 'Frontend submission functionality is officially deprecated.  Please find another solution for this functionality.';
+$lang['fesubmit_allowed'] = 'Allow Frontend Article Submission';
 $lang['help_idlist'] = 'Applicable only to the default action (summary view).  This parameter accepts a comma separated list of numeric article ids and allows further filtering articles to only the article ids specified.  The actual list of articles output is still subject to article status, expiry date, and other parameters.';
 $lang['error_nooptions'] = 'No options specified for field definition';
 $lang['dropdown'] = 'Dropdown';
@@ -106,7 +108,7 @@ $lang['template'] = 'Template';
 $lang['prompt_name'] = 'Name';
 $lang['prompt_default'] = 'Default';
 $lang['prompt_newtemplate'] = 'Create A New Template';
-$lang['help_pagelimit'] = 'Maximum number of items to display (per page).  If this parameter is not supplied all matching items will be displayed.  If it is, and there are more items available than specified in the parameter, text and links will be supplied to allow scrolling through the results';
+$lang['help_pagelimit'] = 'Maximum number of items to display (per page).  If this parameter is not supplied all matching items will be displayed.  If it is, and there are more items available than specified in the parameter, text and links will be supplied to allow scrolling through the results.  The maximum value for this parameter is 1000';
 $lang['prompt_page'] = 'Page';
 $lang['firstpage'] = '&lt;&lt;';
 $lang['prevpage'] = '&lt;';
@@ -276,12 +278,13 @@ $lang['helpaction'] = <<<EOT
 <ul>
 <li>&quot;detail&quot; - to display a specified articleid in detail mode.</li>
 <li>&quot;default&quot; - to display the summary view</li>
-<li>&quot;fesubmit&quot; - <strong>Deprecated</strong> to display the frontend form for allowing users to submit news articles on the front end. Add the <code>{cms_init_editor}</code> tag in the metadata section to initialize the selected wysiwyg editor. (Site Admin >> Global Settings)</li>
+<li>&quot;fesubmit&quot; - <strong>Deprecated</strong> to display the frontend form for allowing users to submit news articles on the front end. Enable this function in the Options tab in the News module admin page. Add the <code>{cms_init_editor}</code> tag in the metadata section to initialize the selected front end WYSIWYG editor. (Site Admin >> Global Settings).</li>
 <li>&quot;browsecat&quot; - to display a browseable category list.</li>
 </ul>
 EOT;
 $lang['help'] = <<<EOF
 <h3>Important Notes</h3>
+<p>Version 2.15 - Front End action needs to be enabled in the options tab of the News module after upgrade!</p>
 <p>Version 2.9 and greater of News has removed the formatpostdate member from the templates, and has also removed the dateformat parameter.  You should be using the cms_date_format modifier (as indicated in the default templates) to format dates, and should be using entry->postdate instead of entry->formatpostdate in your templates.</p>
 <h3>What does this do?</h3>
 <p>News is a module for displaying news events on your page, similar to a blog style, except with more features!.  When the module is installed, a News admin page is added to administration menu that will allow you to select or add a news category.  Once a news category is created or selected, a list of news items for that category will be displayed.  From here, you can add, edit or delete news items for that category.</p>
