@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: changegroupassign.php 8007 2012-06-02 16:27:45Z calguy1000 $
+#$Id: changegroupassign.php 9879 2015-03-28 21:50:46Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -35,7 +35,7 @@ else if (isset($_GET["submitted"])) $submitted = $_GET["submitted"];
 $group_name="";
 
 if (isset($_POST["cancel"])) {
-	redirect("topusers.php".$urlext);
+	redirect("index.php".$urlext);
 	return;
 }
 
@@ -98,7 +98,7 @@ $smarty->assign('groupidlist',implode(',',$groupidlist));
 
 if ($submitted == 1)
   {
-    
+
     foreach($groups as $thisGroup)
       {
 	if( $thisGroup->id <= 0 ) continue;
@@ -111,7 +111,7 @@ if ($submitted == 1)
 	$result = $db->Execute($query, array($thisGroup->id,$userid));
 	$iquery = "INSERT INTO ".cms_db_prefix().
 	  "user_groups (group_id, user_id, create_date, modified_date) VALUES (?,?,?,?)";
-	
+
 	foreach ($_POST as $key=>$value)
 	  {
 	    if (strpos($key,"ug") == 0 && strpos($key,"ug") !== false)
@@ -124,7 +124,7 @@ if ($submitted == 1)
 		  }
 	      }
 	  }
-	
+
 	Events::SendEvent('Core', 'ChangeGroupAssignPost',
 			  array('group' => $thisGroup,
 				'users' => $userops->LoadUsersInGroup($thisGroup->id)));
@@ -204,4 +204,3 @@ include_once("footer.php");
 
 # vim:ts=4 sw=4 noet
 ?>
-
