@@ -24,13 +24,13 @@ define('CMS_DEFAULT_VERSIONCHECK_URL','http://www.cmsmadesimple.org/latest_versi
 define('CMS_SECURE_PARAM_NAME','_sx_');
 define('CMS_USER_KEY','_userkey_');
 
-$session_key = substr(md5($dirname), 0, 8);
+$session_name = 'CMSSESSID'.substr(md5($dirname), 0, 12);
 if( !isset($CMS_INSTALL_PAGE) )
-  {
-    @session_name('CMSSESSID' . $session_key);
+{
+    @session_name($session_name);
     @ini_set('url_rewriter.tags', '');
     @ini_set('session.use_trans_sid', 0);
-  }
+}
 
 #Setup session with different id and start it
 if( isset($CMS_ADMIN_PAGE) || isset($CMS_INSTALL_PAGE) )
@@ -47,6 +47,15 @@ else {
     @session_cache_limiter('public');
 }
 
+if( isset($_COOKIE[$session_name]) ) {
+    // validate the contents of the cookie.
+    if (!preg_match('/^[a-zA-Z0-9,\-]{22,40}$/', $_COOKIE[$session_name]) ) {
+        session_id( uniqid() );
+        session_start();
+        session_regenerate_id();
+    }
+}
+
 if(!@session_id()) session_start();
 
 
@@ -74,6 +83,11 @@ require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'module.func
 require_once($dirname.DIRECTORY_SEPARATOR.'version.php');
 debug_buffer('done loading required files');
 
+if( !isset($CMS_INSTALL_PAGE) && cms_to_bool(ini_get('register_globals')) ) {
+    echo 'FATAL ERROR: For security reasons register_globals must not be enabled for any CMSMS install.  Please adjust your PHP configuration settings to disable this feature.';
+    die();
+}
+
 // sanitize $_GET
 array_walk_recursive($_GET, 'sanitize_input_array');
 // sanitize $_SERVER
