@@ -19,7 +19,7 @@
 #$Id: class.admintheme.inc.php 7596 2011-12-24 22:50:52Z calguy1000 $
 
 /**
- * @package CMS 
+ * @package CMS
  */
 
 
@@ -34,7 +34,7 @@
  * @since   1.11
  * @author  Robert Campbell
  */
-abstract class CmsAdminThemeBase 
+abstract class CmsAdminThemeBase
 {
 	private static $_instance;
 	private $_perms;
@@ -53,7 +53,7 @@ abstract class CmsAdminThemeBase
 	// meta information
 	private $_sectionCount;
 	private $_modulesBySection;
-	
+
 	// tab variables
 	private $_activetab;
 
@@ -96,9 +96,9 @@ abstract class CmsAdminThemeBase
 	public function __get($key)
 	{
 		if( $key == 'cms' ) return cmsms();
-		if( $key == 'themeName' ) 
+		if( $key == 'themeName' )
 			{
-				$class = get_class($this); 
+				$class = get_class($this);
 				if( endswith($class,'Theme') ) $class = substr($class,0,strlen($class)-5);
 				return $class;
 			}
@@ -129,7 +129,7 @@ abstract class CmsAdminThemeBase
 	 * for that particular user.   If cache information is not available, then modules will be loaded and the information
 	 * will be gleaned from the module for that user.
 	 *
-	 * 
+	 *
 	 * @since 1.10
 	 * @access private
 	 * @ignore
@@ -194,7 +194,7 @@ abstract class CmsAdminThemeBase
 
 		// get the info from the cache
 		$usermoduleinfo = $this->_get_user_module_info();
-		if( !is_array($usermoduleinfo) ) 
+		if( !is_array($usermoduleinfo) )
 		{
 			// put mention into the admin log
 			audit(get_userid(FALSE),'Admin Theme','No module information found for user');
@@ -281,10 +281,10 @@ abstract class CmsAdminThemeBase
             {
 				$this->_perms['pagePerms'] = true;
             }
-        $this->_perms['contentPerms'] = $this->_perms['pagePerms'] | $this->_perms['htmlPerms'] | 
+        $this->_perms['contentPerms'] = $this->_perms['pagePerms'] | $this->_perms['htmlPerms'] |
 			(isset($this->_sectionCount['content']) && $this->_sectionCount['content'] > 0);
 
-		// layout        
+		// layout
         $this->_perms['templatePerms'] = check_permission($this->userid, 'Add Templates') |
 			check_permission($this->userid, 'Modify Templates') |
 			check_permission($this->userid, 'Remove Templates');
@@ -301,7 +301,7 @@ abstract class CmsAdminThemeBase
 		// file / image
         $this->_perms['filePerms'] = check_permission($this->userid, 'Modify Files') |
 			(isset($this->_sectionCount['files']) && $this->_sectionCount['files'] > 0);
-    
+
 		// user/group
         $this->_perms['userPerms'] = check_permission($this->userid, 'Add Users') |
 			check_permission($this->userid, 'Modify Users') |
@@ -352,7 +352,7 @@ abstract class CmsAdminThemeBase
      *
      * @param section - section to display
 	 * @access private
-	 * @ignore 
+	 * @ignore
      */
     private function _MenuListSectionModules($section)
     {
@@ -388,7 +388,7 @@ abstract class CmsAdminThemeBase
      *
      * @param subtitle any info to add to the page title
 	 * @access private
-     * @ignore 
+     * @ignore
      */
     private function _populate_admin_navigation($subtitle='')
     {
@@ -399,11 +399,11 @@ abstract class CmsAdminThemeBase
             }
 
 		$config = cmsms()->GetConfig();
-		debug_buffer('before populate admin navigation');	
+		debug_buffer('before populate admin navigation');
         $this->subtitle = $subtitle;
 
 		debug_buffer('before menu items');
-    	    
+
     	$this->_menuItems = array(
 								 // base main menu ---------------------------------------------------------
 								 'main'=>array('url'=>'index.php','parent'=>-1,
@@ -503,10 +503,10 @@ abstract class CmsAdminThemeBase
 													'description'=>lang('editgroup'),'show_in_menu'=>false),
 								 'groupmembers'=>array('url'=>'changegroupassign.php','parent'=>'usersgroups',
 													   'title'=>$this->_FixSpaces(lang('groupassignments')),
-													   'description'=>lang('groupassignmentdescription'),'show_in_menu'=>$this->HasPerm('groupMemberPerms')),                    
+													   'description'=>lang('groupassignmentdescription'),'show_in_menu'=>$this->HasPerm('groupMemberPerms')),
 								 'groupperms'=>array('url'=>'changegroupperm.php','parent'=>'usersgroups',
 													 'title'=>$this->_FixSpaces(lang('groupperms')),
-													 'description'=>lang('grouppermsdescription'),'show_in_menu'=>$this->HasPerm('groupPermPerms')),                    
+													 'description'=>lang('grouppermsdescription'),'show_in_menu'=>$this->HasPerm('groupPermPerms')),
 								 // base extensions menu ---------------------------------------------------------
 								 'extensions'=>array('url'=>'index.php?section=extensions','parent'=>-1,
 													 'title'=>$this->_FixSpaces(lang('extensions')),
@@ -586,13 +586,13 @@ abstract class CmsAdminThemeBase
 											  'title'=>$this->_FixSpaces(lang('ecommerce')),
 											  'description'=>lang('ecommerce_desc'),
 											  'show_in_menu'=>true);
-	
-	
+
+
 		// adjust all the urls to include the session key
 		// and set an icon if we can.
 		foreach( $this->_menuItems as $sectionKey => $sectionArray )
 			{
-				if( isset($sectionArray['url']) && 
+				if( isset($sectionArray['url']) &&
 					(!isset($sectionArray['type']) || $sectionArray['type'] != 'external' ))
 					{
 						$url = $this->_menuItems[$sectionKey]['url'];
@@ -609,7 +609,7 @@ abstract class CmsAdminThemeBase
 						$this->_menuItems[$sectionKey]['url'] = $url;
 					}
 			}
-		
+
 		debug_buffer('before syste modules');
 
 		// add in all of the 'system' modules too
@@ -622,7 +622,7 @@ abstract class CmsAdminThemeBase
 					{
 						$thisModuleKey = $thisKey;
 						$counter = 0;
-				  
+
 						// don't clobber existing keys
 						if (array_key_exists($thisModuleKey,$this->_menuItems))
 							{
@@ -632,7 +632,7 @@ abstract class CmsAdminThemeBase
 										$counter++;
 									}
 							}
-				  
+
 						// if it's a system module...
 						if( ModuleOperations::get_instance()->IsSystemModule($thisModuleKey) )
 							{
@@ -641,11 +641,11 @@ abstract class CmsAdminThemeBase
 																	   'title'=>$this->_FixSpaces($thisVal['name']),
 																	   'description'=>$thisVal['description'],
 																	   'show_in_menu'=>true);
-						  
+
 							}
 					}
 			}
-	
+
 		debug_buffer('before module menu items');
 
 		// add in all of the modules
@@ -687,7 +687,7 @@ abstract class CmsAdminThemeBase
 							}
 					}
 			}
-	
+
 		debug_buffer('after module menu items');
 
 		// remove any top level items that don't have children
@@ -712,9 +712,9 @@ abstract class CmsAdminThemeBase
 					}
 				if( !$found ) unset($this->_menuItems[$oneparent]);
 			}
-	
+
 		// resolve the tree to be doubly-linked,
-		// and make sure the selections are selected            
+		// and make sure the selections are selected
 		foreach ($this->_menuItems as $sectionKey=>$sectionArray)
 			{
 				// link the children to the parents; a little clumsy since we can't
@@ -806,13 +806,13 @@ abstract class CmsAdminThemeBase
 			}
 		  debug_buffer('after populate admin navigation');
     }
-    
+
 
     /**
      * HasPerm
      *
      * Check if the user has one of the aggregate permissions
-     * 
+     *
 	 * @access private
      * @param permission the permission to check.
 	 * @return boolean
@@ -845,7 +845,7 @@ abstract class CmsAdminThemeBase
 		return $this->_menuItems;
 	}
 
-	
+
 	/**
 	 * Return the menu items as a nested tree using recursion.
 	 *
@@ -893,10 +893,10 @@ abstract class CmsAdminThemeBase
 	public function get_navigation_tree($parent = -1,$maxdepth = -1,$usecache = TRUE)
 	{
 		if( is_array($this->_nav_tree) && $usecache) return $this->_nav_tree;
-		
+
 		$nodes = $this->_get_navigation_tree_sub($parent,$maxdepth);
 		if( $usecache ) $this->_nav_tree = $nodes;
-		
+
 		return $nodes;
 	}
 
@@ -958,7 +958,7 @@ abstract class CmsAdminThemeBase
 		$this->_populate_admin_navigation();
 		return $this->_breadcrumbs;
 	}
-	
+
 
 	/**
 	 * Attach some data to the admin theme.
@@ -1044,7 +1044,7 @@ abstract class CmsAdminThemeBase
 			else {
 				$imagePath = '';
 			}
-    	   	
+
 			$config = cmsms()->GetConfig();
 			$str = dirname($config['root_path'].'/'.$config['admin_dir']."/themes/{$this->themeName}/images/{$imagePath}{$imageName}");
 			if (file_exists("{$str}/{$imageName}")) {
@@ -1119,7 +1119,7 @@ abstract class CmsAdminThemeBase
 	static public function GetDefaultTheme()
 	{
 		$tmp = self::GetAvailableThemes();
-		if( is_array($tmp) && count($tmp) ) 
+		if( is_array($tmp) && count($tmp) )
 			{
 				$tmp = array_keys($tmp);
 				$logintheme = get_site_preference('logintheme');
@@ -1129,7 +1129,7 @@ abstract class CmsAdminThemeBase
 			}
 	}
 
-	
+
 	/**
 	 * Retrieve a list of the available admin themes.
 	 *
@@ -1138,7 +1138,7 @@ abstract class CmsAdminThemeBase
 	static public function GetAvailableThemes()
 	{
 		$config = cmsms()->GetConfig();
-			
+
 		$files = glob(cms_join_path($config['admin_path'],'themes').'/*');
 		if( is_array($files) && count($files) )
 			{
@@ -1165,7 +1165,7 @@ abstract class CmsAdminThemeBase
 	static public function &GetThemeObject($name = '')
 	{
 		if( is_object(self::$_instance) ) return self::$_instance;
-		
+
 		if( !$name ) $name = get_preference(get_userid(FALSE),'admintheme',self::GetDefaultTheme());
 		if( class_exists($name) )
 			{
@@ -1249,37 +1249,30 @@ abstract class CmsAdminThemeBase
 	}
 
 
-	/**
-	 * Returns a select list of the pages in the system for use in
-	 * various admin pages.
+    /**
+	 * Return an array of admin pages, suitable for use in a dropdown.
 	 *
-	 * @param string $name - The html name of the select box
-	 * @param string $selected - If a matching id is found in the list, that item
-	 *                           is marked as selected.
-	 * @return string The select list of pages
+	 * @internal
+	 * @since 1.12
+	 * @param bool $none A flag indicating wether 'none' should be the first option.
+	 * @return array The keys of the array are langified strings to display to the user.  The values are URLS.
 	 */
-	public function GetAdminPageDropdown($name,$selected)
+    public function GetAdminPages($none = TRUE)
 	{
 		$opts = array();
-		$opts[ucfirst(lang('none'))] = '';
+		if( $none ) $opts[ucfirst(lang('none'))] = '';
 
 		$depth = 0;
 		$menuItems = $this->get_admin_navigation();
 		foreach( $menuItems as $sectionKey=>$menuItem ) {
-			if( $menuItem['parent'] != -1 ) {
-				continue;
-			}
-			if( !$menuItem['show_in_menu'] || strlen($menuItem['url']) < 1 ) {
-				continue;
-			}
-	     
-			$opts[$menuItem['title']] = $menuItem['url'];
+			if( $menuItem['parent'] != -1 ) continue; // only parent pages
+			if( !$menuItem['show_in_menu'] || strlen($menuItem['url']) < 1 ) continue; // only visible stuff
 
-			if( is_array($menuItem['children']) && 
-				count($menuItem['children']) ) {
+			$opts[$menuItem['title']] = CmsAdminUtils::get_generic_url($menuItem['url']);
+
+			if( is_array($menuItem['children']) && count($menuItem['children']) ) {
 				foreach( $menuItem['children'] as $thisChild ) {
-					if( $thisChild == 'home' || $thisChild == 'logout' ||
-						$thisChild == 'viewsite') {
+					if( $thisChild == 'home' || $thisChild == 'logout' || $thisChild == 'viewsite') {
 						continue;
 					}
 
@@ -1289,10 +1282,28 @@ abstract class CmsAdminThemeBase
 					}
 
 					//$opts['&nbsp;&nbsp;'.$menuChild['title']] = cms_htmlentities($menuChild['url']);
-					$opts['&nbsp;&nbsp;'.$menuChild['title']] = $menuChild['url'];
+					$url = $menuChild['url'];
+					$url = CmsAdminUtils::get_generic_url($url);
+					$opts['&nbsp;&nbsp;'.$menuChild['title']] = $url;
 				}
 			}
 		}
+		return $opts;
+	}
+
+	/**
+	 * Returns a select list of the pages in the system for use in
+	 * various admin pages.
+	 *
+	 * @internal
+	 * @param string $name - The html name of the select box
+	 * @param string $selected - If a matching id is found in the list, that item
+	 *                           is marked as selected.
+	 * @return string The select list of pages
+	 */
+	public function GetAdminPageDropdown($name,$selected)
+	{
+		$opts = $this->GetAdminPages();
 
 		$output = '<select name="'.$name.'">'."\n";
 		foreach( $opts as $key => $value ) {
@@ -1389,7 +1400,7 @@ abstract class CmsAdminThemeBase
 	 *
 	 * @final
 	 * @return string
-	 */ 
+	 */
 	public final function StartTabHeaders()
 	{
 		return '<div id="page_tabs">';
@@ -1404,7 +1415,7 @@ abstract class CmsAdminThemeBase
 	 * @param string The tab title
 	 * @param boolean A flag indicating wether this tab is active.
 	 * @return string
-	 */ 
+	 */
 	public final function SetTabHeader($tabid,$title,$active=false)
 	{
 		$a="";
@@ -1413,7 +1424,7 @@ abstract class CmsAdminThemeBase
 			$a=" class='active'";
 			$this->_activetab = $tabid;
 		}
-		
+
 		$tabid = strtolower(str_replace(' ','_',$tabid));
 		return '<div id="'.$tabid.'"'.$a.'>'.$title.'</div>';
 	}
@@ -1462,13 +1473,13 @@ abstract class CmsAdminThemeBase
 	public final function StartTab($tabid, $params = array())
 	{
 		if (FALSE == empty($this->_activetab) && $tabid == $this->_activetab && FALSE == empty($params['tab_message'])) {
-		
+
 			$message = $this->ShowMessage($this->Lang($params['tab_message']));
 		} else {
-		
+
 			$message = '';
 		}
-		
+
 		return '<div id="' . strtolower(str_replace(' ', '_', $tabid)) . '_c">'.$message;
 	}
 
@@ -1484,7 +1495,7 @@ abstract class CmsAdminThemeBase
 	}
 
 
-	
+
 } // end of class
 
 
