@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: misc.functions.php 9779 2014-12-30 20:40:01Z calguy1000 $
+#$Id: misc.functions.php 9859 2015-03-28 16:16:09Z calguy1000 $
 
 /**
  * Misc functions
@@ -39,7 +39,7 @@ function redirect($to, $noappend=false)
   $_SERVER['PHP_SELF'] = null;
 
   $schema = 'http';
-  
+
   if( class_exists('CmsApp'))
   {
   	if( cmsms()->is_https_request() ) $schema = 'https';
@@ -2176,13 +2176,9 @@ function get_secure_param()
  */
 function cms_to_bool($str)
 {
-  if( is_numeric($str) )
-  {
-    return ((int)$str != 0)?TRUE:FALSE;
-  }
-
+  if( is_numeric($str) ) return ((int)$str != 0)?TRUE:FALSE;
   $str = strtolower($str);
-  if( $str == 'y' || $str == 'yes' || $str == 'true' ) return TRUE;
+  if( $str == 'y' || $str == 'yes' || $str == 'true' || $str == 'on' || $str === '1' ) return TRUE;
   return FALSE;
 }
 
