@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listmodules.php 9229 2014-01-27 14:28:26Z calguy1000 $
+#$Id: listmodules.php 9874 2015-03-28 21:17:37Z JoMorg $
 
 $CMS_ADMIN_PAGE=1;
 $CMS_PREVENT_AUTOINSTALL=1;
@@ -24,7 +24,6 @@ $CMS_FORCE_MODULE_LOAD=1;
 $LOAD_ALL_MODULES=1;
 
 require_once("../include.php");
-require_once(cms_join_path($dirname,'lib','html_entity_decode_utf8.php'));
 
 check_login();
 $thisurl=basename(__FILE__).'?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
@@ -567,12 +566,12 @@ else
 		{
 		  if( $permsok )
 		    {
-		      $actioncol[] .= "<a href=\"{$thisurl}&amp;action=remove&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode_utf8(lang('removeconfirm'),true)."');\">".lang('remove')."</a>";
+		      $actioncol[] .= "<a href=\"{$thisurl}&amp;action=remove&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode(lang('removeconfirm') )."');\">".lang('remove')."</a>";
 		    }
 		  
 		  else
 		    {
-		      $actioncol[] = "<a href=\"{$thisurl}&amp;action=chmod&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode_utf8(lang('changepermissionsconfirm'),true)."');\">".lang('changepermissions')."</a>";
+		      $actioncol[] = "<a href=\"{$thisurl}&amp;action=chmod&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode(lang('changepermissionsconfirm') )."');\">".lang('changepermissions')."</a>";
 		    }
 		}
 	    }
@@ -585,7 +584,7 @@ else
 	      $statuscol[]  = '<span class="important">'.lang('needupgrade').'</span>';
 	      $activecol  = ($dbm[$key]['Active']==true?"<a href='{$thisurl}&amp;action=setfalse&amp;module=".$key."'>".$image_true."</a>":"<a href='{$thisurl}&amp;action=settrue&amp;module=".$key."'>".$image_false."</a>");
 	      if( $maxverok == 1 && $dbm[$key]['Active'] == true) {
-		$actioncol[]  = "<a href=\"{$thisurl}&amp;action=upgrade&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode_utf8(lang('upgradeconfirm'),true)."');\">".lang('upgrade')."</a>";
+		$actioncol[]  = "<a href=\"{$thisurl}&amp;action=upgrade&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode(lang('upgradeconfirm') )."');\">".lang('upgrade')."</a>";
 	      }
 	    }
 	  else // Must be installed
@@ -620,7 +619,7 @@ else
 	      if( !$permsok )
 		{
 		  $statuscol[] = lang('cantremove');
-		  $actioncol[] = "<a href=\"{$thisurl}&amp;action=chmod&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode_utf8(lang('changepermissionsconfirm'),true)."');\">".lang('changepermissions')."</a>";
+		  $actioncol[] = "<a href=\"{$thisurl}&amp;action=chmod&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode(lang('changepermissionsconfirm') )."');\">".lang('changepermissions')."</a>";
 		}
 	    }
 	  
